{% if fleet_comms|length > 0 %}
    <datalist id="fleet-comms-list">
        {% for fleet_comm in fleet_comms %}
            <option value="{{ fleet_comm }}">{{ fleet_comm }}</option>
        {% endfor %}
    </datalist>
{% endif %}
