# Generated by Django 4.0.10 on 2023-05-30 16:51

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("fleetpings", "0012_migrate_app_settings_from_local_py_to_database"),
    ]

    operations = [
        migrations.AddField(
            model_name="fleetcomm",
            name="channel",
            field=models.CharField(
                blank=True,
                help_text="In which channel is the fleet?",
                max_length=255,
                verbose_name="Channel",
            ),
        ),
        migrations.AlterField(
            model_name="fleetcomm",
            name="name",
            field=models.CharField(
                help_text="Short name to identify this comms",
                max_length=255,
                verbose_name="Name",
            ),
        ),
        migrations.AlterUniqueTogether(
            name="fleetcomm",
            unique_together={("name", "channel")},
        ),
    ]
