{% if formup_locations|length > 0 %}
    <datalist id="formup-location-list">
        {% for formup_location in formup_locations %}
            <option value="{{ formup_location }}">{{ formup_location }}</option>
        {% endfor %}
    </datalist>
{% endif %}
