{% load i18n %}

<div class="aa-fleetpings-no-ping">
    <p>
        {% translate "No ping created yet …" %}
    </p>
</div>

<div class="aa-fleetpings-ping" style="display: none;">
    <div class="aa-fleetpings-ping-text"></div>

    <div class="aa-fleetpings-ping-copyresult"></div>

    <div class="form-group clearfix">
        <button
            id="copyFleetPing"
            name="copyFleetPing"
            class="btn btn-primary"
            data-clipboard-action="copy"
            data-clipboard-target=".aa-fleetpings-ping-text"
        >
            {% translate "Copy ping text" %}
        </button>
    </div>
</div>
