# Generated by Django 4.0.10 on 2023-09-22 19:00

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("auth", "0012_alter_user_first_name_max_length"),
        ("fleetpings", "0014_update_models"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="discordpingtarget",
            options={
                "default_permissions": (),
                "verbose_name": "Discord ping target",
                "verbose_name_plural": "Discord ping targets",
            },
        ),
        migrations.AlterModelOptions(
            name="fleetcomm",
            options={
                "default_permissions": (),
                "verbose_name": "Fleet comm",
                "verbose_name_plural": "Fleet comms",
            },
        ),
        migrations.AlterModelOptions(
            name="fleetdoctrine",
            options={
                "default_permissions": (),
                "verbose_name": "Fleet doctrine",
                "verbose_name_plural": "Fleet doctrines",
            },
        ),
        migrations.AlterModelOptions(
            name="fleettype",
            options={
                "default_permissions": (),
                "verbose_name": "Fleet type",
                "verbose_name_plural": "Fleet types",
            },
        ),
        migrations.AlterModelOptions(
            name="formuplocation",
            options={
                "default_permissions": (),
                "verbose_name": "Formup location",
                "verbose_name_plural": "Formup locations",
            },
        ),
        migrations.AlterModelOptions(
            name="setting",
            options={
                "default_permissions": (),
                "verbose_name": "Setting",
                "verbose_name_plural": "Settings",
            },
        ),
        migrations.AlterField(
            model_name="fleettype",
            name="restricted_to_group",
            field=models.ManyToManyField(
                blank=True,
                help_text="Restrict this fleet type to the following groups …",
                related_name="+",
                to="auth.group",
                verbose_name="Group restrictions",
            ),
        ),
        migrations.AlterField(
            model_name="setting",
            name="webhook_verification",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text="Whether to verify webhooks URLs or not. Note: When unchecked, webhook URLs will not be verified, so the app can be used with non-Discord webhooks as well. When disabling webhook verification and using non-Discord webhooks, it is up to you to make sure your webhook understands a payload that is formatted for Discord webhooks.",
                verbose_name="Verify webhooks",
            ),
        ),
    ]
