{% load i18n %}

<option value="">{% translate "Don't ping" %}</option>

{% if use_default_ping_targets %}
    <option value="@here">@here</option>
    <option value="@everyone">@everyone</option>
{% endif %}

{% if ping_targets %}
    {% if use_default_ping_targets %}
        <option value="" disabled></option>
        <optgroup label="{% translate 'Additionally configured ping targets' %}">
            {% include "fleetpings/partials/form/segments/ping-targets-loop.html" %}
        </optgroup>
    {% else %}
        {% include "fleetpings/partials/form/segments/ping-targets-loop.html" %}
    {% endif %}
{% endif %}
