{% load i18n %}

<option value="">{% translate "Please select" %}</option>
<option value="" disabled></option>

{% if use_default_fleet_types %}
    <option value="Roaming" data-embed-color="#81FD2D">{% translate "Roaming Fleet" %}</option>
    <option value="Home Defense" data-embed-color="#F1C40F">{% translate "Home Defense" %}</option>
    <option value="StratOP" data-embed-color="#E67E22">{% translate "StratOP" %}</option>
    <option value="CTA" data-embed-color="#E91E63">{% translate "CTA" %}</option>
{% endif %}

{% if fleet_types|length > 0 %}
    {% if use_default_fleet_types %}
        <option value="" disabled></option>
        <optgroup label="{% translate 'Additionally configured fleet types' %}">
            {% include "fleetpings/partials/form/segments/fleet-type-loop.html" %}
        </optgroup>
    {% else %}
        {% include "fleetpings/partials/form/segments/fleet-type-loop.html" %}
    {% endif %}
{% endif %}
